/**
  *  \file planetscentral/dbclient/fileclient.cc
  *  \brief Client for c2file
  */

#include "planetscentral/dbclient/fileclient.h"
#include "planetscentral/dbclient/dbclient.h"

// CP file file         =>
// FORGET dir           => forgetDirectory
// FTEST file...        =>
// GET file             => getFile
// HELP                 => --
// LS dir               =>
// LSGAME dir           =>
// LSPERM dir           =>
// LSREG dir            =>
// MKDIR parent/dir     => createDirectory
// MKDIRAS user dir     =>
// MKDIRHIER a/b/c      =>
// PING                 => --
// PROPGET dir prop     => getIntProperty, getStringProperty
// PROPSET dir prop val => setProperty
// PUT file content     => putFile
// QUIT                 => --
// RM dir-or-file       =>
// RMDIR dir            => removeDirectory
// SETPERM dir user rwl => setFilePermissions
// STAT file            =>
// STATGAME dir         =>
// STATREG              =>
// USAGE dir            =>
// USER nnn             => setUserPermissions, setRootPermissions

FileClient::FileClient(DbClient& file)
    : file(file)
{ }

void
FileClient::setUserPermissions(string_t user)
{
    file.callVoid(DbRequest().withString("USER").withString(user));
}

void
FileClient::setRootPermissions()
{
    setUserPermissions(string_t());
}

void
FileClient::setFilePermissions(string_t dir, string_t player, string_t perms)
{
    file.callVoid(DbRequest().withString("SETPERM").withString(dir).withString(player).withString(perms));
}

void
FileClient::createDirectory(string_t name)
{
    file.callVoid(DbRequest().withString("MKDIR").withString(name));
}

void
FileClient::createDirectoryTree(string_t name)
{
    file.callVoid(DbRequest().withString("MKDIRHIER").withString(name));
}

void
FileClient::removeDirectory(string_t name)
{
    file.callVoid(DbRequest().withString("RMDIR").withString(name));
}

void
FileClient::forgetDirectory(string_t name)
{
    file.callVoid(DbRequest().withString("FORGET").withString(name));
}

string_t
FileClient::getFile(string_t name)
{
    return file.callString(DbRequest().withString("GET").withString(name));
}

void
FileClient::putFile(string_t name, string_t content)
{
    file.callVoid(DbRequest().withString("PUT").withString(name).withString(content));
}

void
FileClient::removeFile(string_t name)
{
    file.callVoid(DbRequest().withString("RM").withString(name));
}

void
FileClient::setProperty(string_t dir, string_t name, string_t value)
{
    file.callVoid(DbRequest().withString("PROPSET").withString(dir).withString(name).withString(value));
}

void
FileClient::setProperty(string_t dir, string_t name, int32_t value)
{
    file.callVoid(DbRequest().withString("PROPSET").withString(dir).withString(name).withInt(value));
}

string_t
FileClient::getStringProperty(string_t dir, string_t name)
{
    return file.callString(DbRequest().withString("PROPGET").withString(dir).withString(name));
}

int32_t
FileClient::getIntProperty(string_t dir, string_t name)
{
    return file.callInt(DbRequest().withString("PROPGET").withString(dir).withString(name));
}

IntValue*
FileClient::getDirectoryContent(string_t dir)
{
    return file.call(DbRequest().withString("LS").withString(dir));
}
